package com.sundot.airport.blocked.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.sundot.airport.blocked.domain.BlockedRate;

/**
 * 速率Mapper接口
 *
 * @author ruoyi
 * @date 2026-04-13
 */
public interface BlockedRateMapper extends BaseMapper<BlockedRate> {
    /**
     * 查询速率
     *
     * @param id 速率主键
     * @return 速率
     */
    public BlockedRate selectBlockedRateById(Long id);

    /**
     * 查询速率列表
     *
     * @param blockedRate 速率
     * @return 速率集合
     */
    public List<BlockedRate> selectBlockedRateList(BlockedRate blockedRate);

    /**
     * 新增速率
     *
     * @param blockedRate 速率
     * @return 结果
     */
    public int insertBlockedRate(BlockedRate blockedRate);

    /**
     * 修改速率
     *
     * @param blockedRate 速率
     * @return 结果
     */
    public int updateBlockedRate(BlockedRate blockedRate);

    /**
     * 删除速率
     *
     * @param id 速率主键
     * @return 结果
     */
    public int deleteBlockedRateById(Long id);

    /**
     * 批量删除速率
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBlockedRateByIds(Long[] ids);
}
